@@ -1,13 +1,17 @@
 from .detoxify import (
     Detoxify,
     toxic_bert,
+    toxic_albert,
     unbiased_toxic_roberta,
+    unbiased_albert,
     multilingual_toxic_xlm_r,
 )
 
 __all__ = [
     "Detoxify",
     "toxic_bert",
+    "toxic_albert",
     "unbiased_toxic_roberta",
+    "unbiased_albert",
     "multilingual_toxic_xlm_r",
 ]
